# Integration REST API
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/integration-rest-api#overview)
  * [Creating a Processor](https://help.sap.com/docs/leanix/ea/integration-rest-api#creating-a-processor)
  * [Creating a Synchronization Run](https://help.sap.com/docs/leanix/ea/integration-rest-api#creating-a-synchronization-run)
  * [Starting a Synchronization Run](https://help.sap.com/docs/leanix/ea/integration-rest-api#starting-a-synchronization-run)
  * [Canceling a Synchronization Run](https://help.sap.com/docs/leanix/ea/integration-rest-api#canceling-a-synchronization-run)
  * [Retrieving the Status of a Synchronization Run](https://help.sap.com/docs/leanix/ea/integration-rest-api#retrieving-the-status-of-a-synchronization-run)
  * [Retrieving the Details of a Synchronisation Run](https://help.sap.com/docs/leanix/ea/integration-rest-api#retrieving-the-details-of-a-synchronisation-run)
  * [Importing a Collection to Postman](https://help.sap.com/docs/leanix/ea/integration-rest-api#importing-a-collection-to-postman)


How to connect to the Integration API from an external system.
